componenttools.get_proper_contents_of_component
===============================================

.. autofunction:: abjad.tools.componenttools.get_proper_contents_of_component.get_proper_contents_of_component
   :noindex:
